////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file	AVR_Device_Const.h
/// @author	Simon Qian(webmaster@SimonQian.com)
/// @date	Last Update on 2008-04-07
/// @brief	Consts defination for Atmel Tools
/// @par	license
/// 		AVRminiProg is distributed under the terms and conditions of GPLv2, see License.txt
////////////////////////////////////////////////////////////////////////////////////////////////////

/***************************************** Common Responses *****************************************/
void PrepareRSP(uint8,uint16);
/// Response: OK
#define _RSP_OK()							PrepareRSP(RSP_OK,1)
/// Response: Failed
#define _RSP_FAILED()						PrepareRSP(RSP_FAILED,1)
/// Response: Illegal Parameter
#define _RSP_ILLEGAL_PARAMETER()			PrepareRSP(RSP_ILLEGAL_PARAMETER,1)
/// Response: Illegal Memory Type
#define _RSP_ILLEGAL_MEMORY_TYPE()			PrepareRSP(RSP_ILLEGAL_MEMORY_TYPE,1)
/// Response: Illegal Memory Range
#define _RSP_ILLEGAL_MEMORY_RANGE()			PrepareRSP(RSP_ILLEGAL_MEMORY_RANGE,1)
/// Response: Illegal Command
#define _RSP_ILLEGAL_COMMAND()				PrepareRSP(RSP_ILLEGAL_COMMAND,1)
/// Response: Illegal Value
#define _RSP_ILLEGAL_VALUE()				PrepareRSP(RSP_ILLEGAL_VALUE,1)
/// Response: Illegal JTAG ID
#define _RSP_ILLEGAL_JTAG_ID()				PrepareRSP(RSP_ILLEGAL_JTAG_ID,1)
/// Response: No Target Power
#define _RSP_NO_TARGET_POWER()				PrepareRSP(RSP_NO_TARGET_POWER,1)
/// Response: Illegal Power State
#define _RSP_ILLEGAL_POWER_STATE()			PrepareRSP(RSP_ILLEGAL_POWER_STATE,1)
/// Response: Memory
#define _RSP_MEMORY(len)					PrepareRSP(RSP_MEMORY,1 + len)
/// Response: SPI Data
#define _RSP_SPI_DATA()						PrepareRSP(RSP_SPI_DATA,AVRP_TxLen + 1)
/// Response: Self Test
#define _RSP_SELFTEST()						PrepareRSP(RSP_SELFTEST,9)



/***************************************** Common Events *****************************************/
/// Event: Break
#define _EVT_BREAK()						PrepareRSP(EVT_BREAK,6)
/// Event: Target Power On
#define _EVT_TARGET_POWER_ON()				PrepareRSP(EVT_TARGET_POWER_ON,1)
/// Event: Target Power Off
#define _EVT_TARGET_POWER_OFF()				PrepareRSP(EVT_TARGET_POWER_OFF,1)
/// Event: External Reset
#define _EVT_EXT_RESET()					PrepareRSP(EVT_EXT_RESET,1)
/// Event: Target Sleep
#define _EVT_TARGET_SLEEP()					PrepareRSP(EVT_TARGET_SLEEP,1)
/// Event: Target Wakeup
#define _EVT_TARGET_WAKEUP()				PrepareRSP(EVT_TARGET_WAKEUP,1)
/// Event: ICE Power Error
#define _EVT_ICE_POWER_ERROR_STATE()		PrepareRSP(EVT_ICE_POWER_ERROR_STATE,1)
/// Event: ICE Power OK
#define _EVT_ICE_POWER_OK()					PrepareRSP(EVT_ICE_POWER_OK,1)
/// Event: IDR Dirty
#define _EVT_IDR_DIRTY()					PrepareRSP(EVT_IDR_DIRTY,2)


/***************************************** Const Definations *****************************************/
// STK Programming Commands Type
/// STK500 Program Mode Mask
#define AVRP_CMD_PROGMODE_MSK				0xF0
/// STK500 General Command
#define AVRP_CMD_GENERAL					0x00
/// STK500 ISP Command
#define AVRP_CMD_PROGMODE_ISP				0x10
/// STK500 HVPP Command
#define AVRP_CMD_PROGMODE_HVPP				0x20
/// STK500 HVSP Command
#define AVRP_CMD_PROGMODE_HVSP				0x30
/// STK500 XMEGA Command
#define AVRP_CMD_PROGMODE_XMEGA_PDI			

// STK Command Reply
// Success
/// STK500 Response: Command OK
#define AVRP_STATUS_CMD_OK					0x00
// Warnings
/// STK500 Response: Command Timeout
#define AVRP_STATUS_CMD_TOUT				0x80
/// STK500 Response: Wait Busy Timeout
#define AVRP_STATUS_RDY_BSY_TOUT			0x81
/// STK500 Response: Missing Parameter
#define AVRP_STATUS_SET_PARAM_MISSING		0x82
// Errors
/// STK500 Response: Command Failed
#define AVRP_STATUS_CMD_FAILED				0xC0
/// STK500 Response: Checksum error
#define AVRP_STATUS_CMD_CHECKSUM_ERROR		0xC1
/// STK500 Response: Unknown Command
#define AVRP_STATUS_CMD_UNKNOWN				0xC9
/// STK500 Response: Illegal Parameter
#define AVRP_STATUS_CMD_ILLEGAL_PARAMETER	0xCA

// STK Status
#define AVRP_STATUS_ISP_READY				0x00
#define AVRP_STATUS_CONN_FAIL_MOSI			0x01
#define AVRP_STATUS_CONN_FAIL_RST			0x02
#define AVRP_STATUS_CONN_FAIL_SCK			0x04
#define AVRP_STATUS_TGT_NOT_DETECTED		0x10
#define AVRP_STATUS_TGT_REVERSE_INSERTED	0x20

// STK Programming Command
/// STK500 Programming Command Mask
#define AVRP_CMD_MSK						0x0F
/// STK500 Programming Command: EnterProgramMode
#define AVRP_CMD_ENTER_PROGMODE				0x00
/// STK500 Programming Command: ExitProgramMode
#define AVRP_CMD_EXIT_PROGMODE				0x01
/// STK500 Programming Command: ChipErase
#define AVRP_CMD_CHIP_ERASE					0x02
/// STK500 Programming Command: ProgramFlash
#define AVRP_CMD_PROGRAM_FLASH				0x03
/// STK500 Programming Command: ReadFlash
#define AVRP_CMD_READ_FLASH					0x04
/// STK500 Programming Command: ProgramEEPROM
#define AVRP_CMD_PROGRAM_EEPROM				0x05
/// STK500 Programming Command: ReadEEPROM
#define AVRP_CMD_READ_EEPROM				0x06
/// STK500 Programming Command: ProgramFuse
#define AVRP_CMD_PROGRAM_FUSE				0x07
/// STK500 Programming Command: ReadFuse
#define AVRP_CMD_READ_FUSE					0x08
/// STK500 Programming Command: ProgramLockbit
#define AVRP_CMD_PROGRAM_LOCKBIT			0x09
/// STK500 Programming Command: ReadLockbit
#define AVRP_CMD_READ_LOCKBIT				0x0A
/// STK500 Programming Command: ReadSignature
#define AVRP_CMD_READ_SIGNATURE				0x0B
/// STK500 Programming Command: ReadOSCCAL
#define AVRP_CMD_READ_OSCCAL				0x0C
/// STK500 Programming Command: SpecialOperation
#define AVRP_CMD_SPECIAL_OPERATION			0x0D

#define AVRP_CMD_ENTER_PROGMODE_HVSP_STK600	0x3D
#define AVRP_CMD_LEAVE_PROGMODE_HVSP_STK600	0x3E

// XPROG Command
#define AVRP_CMD_XPROG						0x50
#define AVRP_CMD_XPROG_SETMODE				0x51

// AVR32 JTAG Programming Command
#define AVRP_CMD_JTAG_AVR32					0x80
#define AVRP_CMD_ENTER_PROGMODE_JTAG_AVR32	0x81
#define AVRP_CMD_LEAVE_PROGMODE_JTAG_AVR32	0x82

// AVR JTAG Programming Command
#define AVRP_CMD_JTAG_AVR					0x90

// STK Test Command
#define AVRP_CMD_ENTER_TESTMODE				0x60
#define AVRP_CMD_LEAVE_TESTMODE				0x61
#define AVRP_CMD_CHIP_WRITE					0x62
#define AVRP_CMD_PROGRAM_FLASH_PARTIAL		0x63
#define AVRP_CMD_PROGRAM_EEPROM_PARTIAL		0x64
#define AVRP_CMD_PROGRAM_SIGNATURE_ROW		0x65
#define AVRP_CMD_READ_FLASH_MARGIN			0x66
#define AVRP_CMD_READ_EEPROM_MARGIN			0x67
#define AVRP_CMD_READ_SIGNATURE_ROW_MARGIN	0x68
#define AVRP_CMD_PROGRAM_TEST_FUSE			0x69
#define AVRP_CMD_READ_TEST_FUSE				0x6A
#define AVRP_CMD_PROGRAM_HIDDEN_FUSE_LOW	0x6B
#define AVRP_CMD_READ_HIDDEN_FUSE_LOW		0x6C
#define AVRP_CMD_PROGRAM_HIDDEN_FUSE_HIGH	0x6D
#define AVRP_CMD_READ_HIDDEN_FUSE_HIGH		0x6E
#define AVRP_CMD_PROGRAM_HIDDEN_FUSE_EXT	0x6F
#define AVRP_CMD_READ_HIDDEN_FUSE_EXT		0x70

// STK General Command
/// STK500 Common Command: SignOn
#define AVRP_CMD_SIGN_ON					0x01
/// STK500 Common Command: SetParameter
#define AVRP_CMD_SET_PARAMETER				0x02
/// STK500 Common Command: GetParameter
#define AVRP_CMD_GET_PARAMETER				0x03
/// STK500 Common Command: CalibrateOSCCAL
#define AVRP_CMD_OSCCAL						0x05
/// STK500 Common Command: LoadAddress
#define AVRP_CMD_LOAD_ADDRESS				0x06
/// STK500 Common Command: FirmwareUpgrade
#define AVRP_CMD_FIRMWARE_UPGRADE			0x07
/// STK500 Common Command: ResetForProtection
#define AVRP_CMD_RESET_PROTECTION			0x0A
/// STK500 Common Command: CheckTargetConnection
#define AVRP_CMD_CHECK_TARGET_CONNECTION	0x0D
#define AVRP_CMD_LOAD_RC_IDTABLE			0x0E
#define AVRP_CMD_LOAD_EC_IDTABLE			0x0F

// STK Parameters
/// STK500 Parameter: BuildNumberLow
#define AVRP_PARAM_BUILD_NUMBER_LOW			0x80
/// STK500 Parameter: BuildNumberHigh
#define AVRP_PARAM_BUILD_NUMBER_HIGH		0x81
/// STK500 Parameter: HardwareVersion
#define AVRP_PARAM_HW_VER					0x90
/// STK500 Parameter: SoftwareMajorVersion
#define AVRP_PARAM_SW_MAJOR					0x91
/// STK500 Parameter: SoftwareMinorVersion
#define AVRP_PARAM_SW_MINOR					0x92
/// STK500 Parameter: TargetVoltage
#define AVRP_PARAM_VTARGET					0x94
#define AVRP_PARAM_VADJUST					0x95
#define AVRP_PARAM_OSC_PSCALE				0x96
#define AVRP_PARAM_OSC_CMATCH				0x97
/// STK500 Parameter: SCKDurationForISP
#define AVRP_PARAM_SCK_DURATION				0x98
#define AVRP_PARAM_TOPCARD_DETECT			0x9A
#define AVRP_PARAM_STATUS					0x9C
#define AVRP_PARAM_DATA						0x9D
/// STK500 Parameter: ResetPolarity(AVR or S51/52)
#define AVRP_PARAM_RESET_POLARITY			0x9E
#define AVRP_PARAM_CONTROLLER_INIT			0x9F
// STK600 Parameters
#define AVRP_PARAM_STATUS_TGT_CONN			0xA1
#define AVRP_PARAM_DISCHARGEDELAY			0xA4
#define AVRP_PARAM_SOCKETCARD_ID			0xA5
#define AVRP_PARAM_ROUTINGCARD_ID			0xA6
#define AVRP_PARAM_EXPCARD_ID				0xA7
#define AVRP_PARAM_SW_MAJOR_SLAVE1			0xA8
#define AVRP_PARAM_SW_MINOR_SLAVE1			0xA9
#define AVRP_PARAM_SW_MAJOR_SLAVE2			0xAA
#define AVRP_PARAM_SW_MINOR_SLAVE2			0xAB
#define AVRP_PARAM_BOARD_ID_STATUS			0xAD
#define AVRP_PARAM_RESET					0xB4
// JTAG
#define AVRP_PARAM_JTAG_ALLOW_FULL_PAGE_STREAM	0x50
#define AVRP_PARAM_JTAG_EEPROM_PAGE_SIZE	0x52
#define AVRP_PARAM_JTAG_DAISY_BITS_BEFORE	0x53
#define AVRP_PARAM_JTAG_DAISY_BITS_AFTER	0x54
#define AVRP_PARAM_JTAG_DAISY_UNITS_BEFORE	0x55
#define AVRP_PARAM_JTAG_DAISY_UNITS_AFTER	0x56
// 2 bytes Parameters
#define AVRP_PARAM2_SCK_DURATION			0xC0
#define AVRP_PARAM2_CLOCK_CONF				0xC1
#define AVRP_PARAM2_AREF0					0xC2
#define AVRP_PARAM2_AREF1					0xC3
// JTAG
#define AVRP_PARAM2_JTAG_FLASH_SIZE_H		0xC5
#define AVRP_PARAM2_JTAG_FLASH_SIZE_L		0xC6
#define AVRP_PARAM2_JTAG_FLASH_PAGE_SIZE	0xC7
#define AVRP_PARAM2_RC_ID_TABLE_REV			0xC8
#define AVRP_PARAM2_EC_ID_TABLE_REV			0xC9

// STK600 XPROG
// XPROG Commands
#define AVRP_XPRG_CMD_ENTER_PROGMODE		0x01
#define AVRP_XPRG_CMD_LEAVE_PROGMODE		0x02
#define AVRP_XPRG_CMD_ERASE					0x03
#define AVRP_XPRG_CMD_WRITE_MEM				0x04
#define AVRP_XPRG_CMD_READ_MEM				0x05
#define AVRP_XPRG_CMD_CRC					0x06
#define AVRP_XPRG_CMD_SET_PARAM				0x07
// XPROG Memory Type
#define AVRP_XPRG_MEM_TYPE_APPL				1
#define AVRP_XPRG_MEM_TYPE_BOOT				2
#define AVRP_XPRG_MEM_TYPE_EEPROM			3
#define AVRP_XPRG_MEM_TYPE_FUSE				4
#define AVRP_XPRG_MEM_TYPE_LOCKBITS			5
#define AVRP_XPRG_MEM_TYPE_USERSIG			6
#define AVRP_XPRG_MEM_TYPE_FACTORY_CALIBRATION	7
// XPROG Erase Type
#define AVRP_XPRG_ERASE_CHIP				1
#define AVRP_XPRG_ERASE_APP					2
#define AVRP_XPRG_ERASE_BOOT				3
#define AVRP_XPRG_ERASE_EEPROM				4
#define AVRP_XPRG_ERASE_APP_PAGE			5
#define AVRP_XPRG_ERASE_BOOT_PAGE			6
#define AVRP_XPRG_ERASE_EEPROM_PAGE			7
#define AVRP_XPRG_ERASE_USERSIG				8
// XPROG Write Mode
#define AVRP_XPRG_MEM_WRITE_ERASE			0
#define AVRP_XPRG_MEM_WRITE_WRITE			1
// XPROG CRC Type
#define AVRP_XPRG_CRC_APP					1
#define AVRP_XPRG_CRC_BOOT					2
#define AVRP_XPRG_CRC_FLASH					3
// XPROG Error Code
#define AVRP_XPRG_ERR_OK					0
#define AVRP_XPRG_ERR_FAILED				1
#define AVRP_XPRG_ERR_COLLISION				2
#define AVRP_XPRG_ERR_TIMEOUT				3
// XPROG parameters of different sizes
// 4-byte address
#define AVRP_XPRG_PARAM_NVMBASE				0x01
// 2-byte page size
#define AVRP_XPRG_PARAM_EEPPAGESIZE			0x02

// STK500v2 State Machine
/// STK500v2 State Machine: MessageStart State
#define STATEMACHINE_MESSAGE_START			0x01
/// STK500v2 State Machine: SequenceNumber State
#define STATEMACHINE_SEQUENCE_NUMBER		0x02
/// STK500v2 State Machine: MessageSize State
#define STATEMACHINE_MESSAGE_SIZE			0x03
/// STK500v2 State Machine: Token State
#define STATEMACHINE_TOKEN					0x04
/// STK500v2 State Machine: MessageBody State
#define STATEMACHINE_MESSAGE_BODY			0x05
/// STK500v2 State Machine: CRC State
#define STATEMACHINE_CRC					0x06

// STK500v2 Package Char
/// STK500v2 State Machine: MessageStartCharacter
#define MESSAGE_START_CHAR					0x1B
/// STK500v2 State Machine: TokenCharacter
#define TOKEN_CHAR							0x0E

// ICE
// ICE Commands
/// STK500v2 Command: Invalid
#define JTAGICE_CMND_INVALID				0xFF
/// STK500v2 Command: SignOff
#define JTAGICE_CMND_SIGN_OFF				0x00
/// STK500v2 Command: SignOn
#define JTAGICE_CMND_GET_SIGN_ON			0x01
/// STK500v2 Command: SetParameter
#define JTAGICE_CMND_SET_PARAMETER			0x02
/// STK500v2 Command: GetParameter
#define JTAGICE_CMND_GET_PARAMETER			0x03
/// STK500v2 Command: WriteMemory
#define JTAGICE_CMND_WRITE_MEMORY			0x04
/// STK500v2 Command: ReadMemory
#define JTAGICE_CMND_READ_MEMORY			0x05
/// STK500v2 Command: WritePC
#define JTAGICE_CMND_WRITE_PC				0x06
/// STK500v2 Command: ReadPC
#define JTAGICE_CMND_READ_PC				0x07
/// STK500v2 Command: GO
#define JTAGICE_CMND_GO						0x08
/// STK500v2 Command: SingleStep
#define JTAGICE_CMND_SINGLE_STEP			0x09
/// STK500v2 Command: ForcedStop
#define JTAGICE_CMND_FORCED_STOP			0x0A
/// STK500v2 Command: Reset
#define JTAGICE_CMND_RESET					0x0B
/// STK500v2 Command: SetDeviceDescriptor
#define JTAGICE_CMND_SET_DEVICE_DESCRIPTOR	0x0C
/// STK500v2 Command: ErasePageSPM
#define JTAGICE_CMND_ERASEPAGE_SPM			0x0D
/// STK500v2 Command: GetSync
#define JTAGICE_CMND_GET_SYNC				0x0F
/// STK500v2 Command: SelfTest
#define JTAGICE_CMND_SELFTEST				0x10
/// STK500v2 Command: SetBreak
#define JTAGICE_CMND_SET_BREAK				0x11
/// STK500v2 Command: GetBreak
#define JTAGICE_CMND_GET_BREAK				0x12
/// STK500v2 Command: ChipErase
#define JTAGICE_CMND_CHIP_ERASE				0x13
/// STK500v2 Command: EnterProgramMode
#define JTAGICE_CMND_ENTER_PROGMODE			0x14
/// STK500v2 Command: LeaveProgramMode
#define JTAGICE_CMND_LEAVE_PROGMODE			0x15
/// STK500v2 Command: SetNParameters
#define JTAGICE_CMND_SET_N_PARAMETERS		0x16
/// STK500v2 Command: ClearBreak
#define JTAGICE_CMND_CLR_BREAK				0x1A
/// STK500v2 Command: RunToAddr
#define JTAGICE_CMND_RUN_TO_ADDR			0x1C
/// STK500v2 Command: SPI_CMD
#define JTAGICE_CMND_SPI_CMD				0x1D
/// STK500v2 Command: ClearEvents
#define JTAGICE_CMND_CLEAR_EVENTS			0x22
/// STK500v2 Command: RestoreTarget
#define JTAGICE_CMND_RESTORE_TARGET			0x23
/// STK500v2 Command: CallSTK500
#define JTAGICE_CMND_PROG_PACKET			0x2F

// ICE Response
/// STK500v2 Response: OK
#define RSP_OK								0x80
/// STK500v2 Response: Failed
#define RSP_FAILED							0xA0
/// STK500v2 Response: Illegal Parameter
#define RSP_ILLEGAL_PARAMETER				0xA1
/// STK500v2 Response: ParameterError
#define RSP_PARAMETER						0x81
/// STK500v2 Response: IllegalMemoryType
#define RSP_ILLEGAL_MEMORY_TYPE				0xA2
/// STK500v2 Response: IllegalMemoryRange
#define RSP_ILLEGAL_MEMORY_RANGE			0xA3
/// STK500v2 Response: SendMemory
#define RSP_MEMORY							0x82
/// STK500v2 Response: GetBreak
#define RSP_GET_BREAK						0x83
/// STK500v2 Response: IllegalEmulatorMode
#define RSP_ILLEGAL_EMULATOR_MODE			0xA4
/// STK500v2 Response: IllegalMCUState
#define RSP_ILLEGAL_MCU_STATE				0xA5
/// STK500v2 Response: GetPC
#define RSP_PC								0x84
/// STK500v2 Response: DoSelfTest
#define RSP_SELFTEST						0x85
/// STK500v2 Response: SendSPI_Data
#define RSP_SPI_DATA						0x88
/// STK500v2 Response: Illegal Command
#define RSP_ILLEGAL_COMMAND					0xAA
/// STK500v2 Response: Illegal Value
#define RSP_ILLEGAL_VALUE					0xA6
/// STK500v2 Response: SignOn
#define RSP_SIGN_ON							0x86
/// STK500v2 Response: Illegal Breakpoint
#define RSP_ILLEGAL_BREAKPOINT				0xA8
/// STK500v2 Response: Illegal JTAGID
#define RSP_ILLEGAL_JTAG_ID					0xA9
/// STK500v2 Response: NoTargetPower
#define RSP_NO_TARGET_POWER					0xAB
/// STK500v2 Response: DebugWriteSyncFailed
#define RSP_DEBUGWIRE_SYNC_FAILED			0xAC
/// STK500v2 Response: IllegalPowerState
#define RSP_ILLEGAL_POWER_STATE				0xAD
// ICE Event
#define EVT_INVALID							0x00
#define EVT_BASE							0xE0
#define EVT_BREAK							0xE0
#define EVT_RUN								0xE1
#define EVT_TARGET_POWER_ON					0xE4
#define EVT_TARGET_POWER_OFF				0xE5
#define EVT_DEBUG							0xE6
#define EVT_EXT_RESET						0xE7
#define EVT_TARGET_SLEEP					0xE8
#define EVT_TARGET_WAKEUP					0xE9
#define EVT_ICE_POWER_ERROR_STATE			0xEA
#define EVT_ICE_POWER_OK					0xEB
#define EVT_IDR_DIRTY						0xEC
#define EVT_NONE							0xEF
#define EVT_PROGRAM_BREAK					0xF1
#define EVT_PDSB_BREAK						0xF2
#define EVT_PDSMB_BREAK						0xF3
#define EVT_ERROR_PHY_X					
	#define ERROR_PHY_FORCE_BREAK_TIMEOUT	0xE2
	#define ERROR_PHY_RELEASE_BREAK_TIMEOUT	0xE3
	#define ERROR_PHY_MAX_BIT_LENGTH_DIFF	0xED
	#define ERROR_PHY_SYNC_TIMEOUT			0xF0
	#define ERROR_PHY_SYNC_TIMEOUT_BAUD		0xF4
	#define ERROR_PHY_SYNC_OUT_OF_RANGE		0xF5
	#define ERROR_PHY_SYNC_WAIT_TIMEOUT		0xF6
	#define ERROR_PHY_RECEIVE_TIMEOUT		0xF7
	#define ERROR_PHY_RECEIVED_BREAK		0xF8
	#define ERROR_PHY_OPT_RECEIVE_TIMEOUT	0xF9
	#define ERROR_PHY_OPT_RECEIVED_BREAK	0xFA
	#define RESULT_PHY_NO_ACTIVITY			0xFB
// ICE Memory Type
#define MEMORY_TYPE_IO_SHADOW				0x30
#define MEMORY_TYPE_SRAM					0x20
#define MEMORY_TYPE_EEPROM					0x22
#define MEMORY_TYPE_EVENT					0x60
#define MEMORY_TYPE_SPM						0xA0
#define MEMORY_TYPE_FLASH_PAGE				0xB0
#define MEMORY_TYPE_EEPROM_PAGE				0xB1
#define MEMORY_TYPE_FUSE_BITS				0xB2
#define MEMORY_TYPE_LOCK_BITS				0xB3
#define MEMORY_TYPE_SIGN_JTAG				0xB4
#define MEMORY_TYPE_OSCCAL_BYTE				0xB5
#define MEMORY_TYPE_CAN						0xB6
// ICE Parameter
/// STK500v2 Parameter: HardwareVersion
#define PARAM_HW_VERSION					0x01
/// STK500v2 Parameter: FirmwareVersion
#define PARAM_FW_VERSION					0x02
/// STK500v2 Parameter: EmulatorMode
#define PARAM_EMULATOR_MODE					0x03
/// Emulator Mode DebugWire
# define EMULATOR_MODE_DEBUGWIRE			0x00
/// Emulator Mode JTAG for AVR
# define EMULATOR_MODE_JTAG					0x01
/// Emulator Mode HV Programming
# define EMULATOR_MODE_HV					0x02
/// Emulator Mode SPI Programming
# define EMULATOR_MODE_SPI					0x03
/// Emulator Mode JTAG for AVR XMega
# define EMULATOR_MODE_XMEGA_JTAG			0x05
/// Emulator Mode JTAG for AVR32
# define EMULATOR_MODE_AVR32_JTAG			0x06
#define PARAM_IREG							0x04
#define PARAM_BAUD_RATE						0x05
/// STK500v2 Parameter: Target Voltage
#define PARAM_OCD_VTARGET					0x06
#define PARAM_OCD_JTAG_CLK					0x07
#define PARAM_OCD_BREAK_CAUSE				0x08
#define PARAM_TIMERS_RUNNING				0x09
#define PARAM_BREAK_ON_CHANGE_FLOW			0x0A
#define PARAM_BREAK_ADDR1					0x0B
#define PARAM_BREAK_ADDR2					0x0C
#define PARAM_COMBBREAKCTRL					0x0D
/// STK500v2 Parameter: Read JTAGID
#define PARAM_JTAGID						0x0E
#define PARAM_UNITS_BEFORE					0x0F
#define PARAM_UNITS_AFTER					0x10
#define PARAM_BIT_BEFORE					0x11
#define PARAM_BIT_ATER						0x12
#define PARAM_EXTERNAL_RESET				0x13
#define PARAM_FLASH_PAGE_SIZE				0x14
#define PARAM_EEPROM_PAGE_SIZE				0x15
#define PARAM_UNUSED1						0x16
#define PARAM_PSB0							0x17
#define PARAM_PSB1							0x18
#define PARAM_PROTOCOL_DEBUG_EVENT			0x19
#define PARAM_MCU_STATE						0x1A
# define STOPPED							0x00
# define RUNNING							0x01
# define PROGRAMMING						0x02
#define PARAM_DAISY_CHAIN_INFO				0x1B
#define PARAM_BOOT_ADDRESS					0x1C
#define PARAM_TARGET_SIGNATURE				0x1D
#define PARAM_DEBUGWIRE_BAUDRATE			0x1E
/// STK500v2 Parameter: EntryPoint
#define PARAM_PROGRAM_ENTRY_POINT			0x1F
#define PARAM_PACKET_PARSING_ERRORS			0x40
#define PARAM_VALID_PACKETS_RECEIVED		0x41
#define PARAM_INTERCOMMUNICATION_TX_FAILURES	0x42
#define PARAM_INTERCOMMUNICATION_RX_FAILURES	0x43
#define PARAM_CRC_ERRORS					0x44
#define PARAM_POWER_SOURCE					0x45
# define POWER_EXTERNAL						0x00
# define POWER_USB							0x01
#define PARAM_CAN_FLAG						0x22
# define DONT_READ_CAN_MAILBOX				0x00
# define READ_CAN_MAILBOX					0x01
#define PARAM_ENABLE_IDR_IN_RUN_MODE		0x23
# define ACCESS_OSCCAL						0x00
# define ACCESS_IDR							0x01
#define PARAM_ALLOW_PAGEPROGRAMMING_IN_SCANCHAIN	0x24
# define PAGEPROG_NOT_ALLOWED				0x00
# define PAGEPROG_ALLOWED					0x01
