////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file	AVR_Device_Phenix_ProgramBlock.h
/// @author	Simon Qian(webmaster@SimonQian.com)
/// @date	Last Update on 2008-04-07
/// @brief	Define offline programming block, can ONLY be included by AVR_Device_Phenix.c
/// @par	license
/// 		AVRminiProg is distributed under the terms and conditions of GPLv2, see License.txt
////////////////////////////////////////////////////////////////////////////////////////////////////
#ifndef __AVR_DEVICE_PHENIX_PROGRAMBLOCK_H__
#define __AVR_DEVICE_PHENIX_PROGRAMBLOCK_H__

#if AVRP_Phenix_BlockPosition == AVRP_Phenix_BlockInStaticFlash
PROGMEM uint8 AVRP_Phenix_BlockData[] = {
	// System Block:0(67 bytes)
	// Valid:0,NumOfInterfaces:1,NumOfTargets:2
	0,1,1,
	// Interfaces Array:3(4 * AVRP_Phenix_Constants_NumOfInterfaces = 32 bytes)
	67,0,0,0,		246,0,0,0,	0,0,0,0,	0,0,0,0,	0,0,0,0,	0,0,0,0,	0,0,0,0,	0,0,0,0,
	// Target Array:35(4 * AVRP_Phenix_Constants_NumOfTargets = 32 bytes)
	(uint8)429,(uint8)(429 >> 8),0,0,	0,0,0,0,	0,0,0,0,	0,0,0,0,	0,0,0,0,	0,0,0,0,	0,0,0,0,	0,0,0,0,

	// Interface Block:67(362 bytes)
	// Interface0 Mega48 HVPP:67(179 bytes)
	// ProgMode:0,EEPageSize:1,FlashPageSize:2,Reserved:12 (16 bytes)
	0x20,0x04,0x40,0x00,0,0,0,0,0,0,0,0,0,0,0,0,
	// Package Array:16(2 * AVRP_Phenix_Constants_NumOfPackages = 28 bytes)
	0,7,	12,2,	19,2,	26,4,	35,2,	42,4,	51,2,	58,3,	66,1,	72,3,	80,1,	86,1,	92,1,	98,32,
	// Packages:44
	// Package EnterProgMode:0(12 bytes)
	0,0,7,0,0,			0x64,0x00,0x05,0x01,0x0F,0x01,0x00,
	// Package ExitProgMode:12(7 bytes)
	0,0,2,0,0,			0x0F,0x0F,
	// Package ChipErase:19(7 bytes)
	0,0,2,0,0,			0x00,0x0A,
	// Package ProgramFlash:26(9 bytes)
	0,2,4,64,0,			0x00,0x40,0xCD,0x06,
	// Package ReadFlash:35(7 bytes)
	0,2,2,0,0,			0x00,0x40,
	// Package ProgramEEPROM:42(9 bytes)
	0,2,4,4,0,			0x00,0x04,0xC5,0x05,
	// Package ReadEEPROM:51(7 bytes)
	0,2,2,0,0,			0x00,0x04,
	// Package ProgramFuse:58(8 bytes)
	0,1,1,1,0,			0x00,0x00,0x05,
	// Package ReadFuse:66(6 bytes)
	0,1,1,0,0,			0x00,
	// Package ProgramLockbit:72(8 bytes)
	0,0,1,1,0,			0x00,0x00,0x05,
	// Package ReadLockbit:80(6 bytes)
	0,0,1,0,0,			0x00,
	// Package ReadSignature:86(6 bytes)
	0,1,1,0,0,			0x00,
	// Package ReadOSCCAL:92(6 bytes)
	0,1,1,0,0,			0x00,
	// Package SpecialOperation:98(37 bytes)
	0,0,32,0,0,			0x0E,0x1E,0x0F,0x1F,0x2E,0x3E,0x2F,0x3F,0x4E,0x5E,0x4F,0x5F,0x6E,0x7E,0x6F,0x7F,0x66,0x76,0x67,0x77,0x6A,0x7A,0x6B,0x7B,0xBE,0xFD,0x00,0x01,0x00,0x00,0x00,0x00,

	// Interface1 Mega48 ISP:246(183 bytes)
	// ProgMode:0,EEPageSize:1,FlashPageSize:2,Reserved:12 (16 bytes)
	0x10,0x04,0x40,0x00,0,0,0,0,0,0,0,0,0,0,0,0,
	// Package Array:16(2 * AVRP_Phenix_Constants_NumOfPackages = 28 bytes)
	0,11,	16,2,	23,6,	34,9,	48,3,	56,9,	70,3,	78,3,	86,5,	96,3,	104,5,	114,5,	124,5,	134,0,
	// Packages:44(139 bytes)
	// Package EnterProgMode:0(16 bytes)
	0,0,11,0,0,			0xC8,0x64,0x19,0x20,0x00,0x53,0x03,0xAC,0x53,0x00,0x00,
	// Package ExitProgMode:16(7 bytes)
	0,0,2,0,0,			0x01,0x01,
	// Package ChipErase:23(11 bytes)
	0,0,6,0,0,			0x09,0x00,0xAC,0x88,0xFC,0x22,
	// Package ProgramFlash:34(14 bytes)
	0,2,9,64,0,			0x00,0x40,0xC1,0x06,0x40,0x4C,0x20,0xFF,0xFF,
	// Package ReadFlash:48(8 bytes)
	0,2,3,0,0,			0x00,0x40,0x20,
	// Package ProgramEEPROM:56(14 bytes)
	0,2,9,4,0,			0x00,0x04,0xC1,0x05,0xC1,0xC2,0xA0,0xFF,0xFF,
	// Package ReadEEPROM:70(8 bytes)
	0,2,3,0,0,			0x00,0x04,0xA0,
	// Package ProgramFuse:78(8 bytes)
	0,0xF0,3,1,0,		0xAC,0xA0,0x00,
	// Package ReadFuse:86(10 bytes)
	0,0xF1,5,0,0,		0x04,0x50,0x00,0x00,0x00,
	// Package ProgramLockbit:96(8 bytes)
	0,0,3,1,0,			0xAC,0xE0,0x00,
	// Package ReadLockbit:104(10 bytes)
	0,0,5,0,0,			0x04,0x58,0x00,0x00,0x00,
	// Package ReadSignature:114(10 bytes)
	3,1,5,0,0,			0x04,0x30,0x00,0x00,0x00,
	// Package ReadOSCCAL:124(10 bytes)
	3,1,5,0,0,			0x04,0x38,0x00,0x00,0x00,
	// Package SpecialOperation:134(5 bytes)
	0,0,0,0,0,

	// Target Block:429
	// Target0:429( bytes)
	// Supported Interfaces:0,
	// 0x02,
	0x03,
	// Operations:1
//	0x62,0xF6,
	0x62,0x36,
//	0x7F,0xFF,
	// Program Speed:3(add 0x80 to enable)
//	0x80,
	0x00,
	// Program Data Array:4(16 * 2 = 32 bytes)
//	Signature,	FuseBefore,	EraseCmd,	FuseAfter,	Caliberate,	OSCCAL,		Special,	Lockbits,	Reserved0,	Reserved1,	Reserved2,	Reserved3,	Reserved4,	Reserved5,	EEPROM,		Flash,
	0,0,		0,0,		3,0,		4,0,		0,0,		0,0,		8,0,		10,0,		0,0,		0,0,		0,0,		0,0,		0,0,		0,0,		0,0,		12,0,
	// Program Data:36
	// Signature:0(3 bytes)
	0x1E,0x92,0x05,
	// Fuse Before(size,	data):3(4 btyes)
//	0,	0x00,0x00,0x00,
	// Chip Erase Type:3(reserved for XMega,1 byte)
	0x00,
	// Fuse After:4(size,	data,4 bytes)
	3,	0xE2,0xDC,0xFF,
	// Caliberate
	// Special:8(2 bytes)
	0x58,0x0E,
	// Lockbits:10(size,	data,2 bytes)
	1,	0xFC,
	// EEPROM(NumOfPages(2),StartAddress(4),PageSize(2)		data)
//	0x03,0x00,	0,0,0,0,	0,0,
//	0x00,0x01,0x02,0x03,
//	0x04,0x05,0x06,0x07,
//	0x08,0x09,0x0A,0x0B,
	// End of EEPROM
	// Flash:12(NumOfPages(2),StartAddress(4),PageSize(2)		data,3781 bytes)
	1,0,	0,0,0,0,	0,0,
0xB6,0xC6,0x18,0x95,0x18,0x95,0x18,0x95,0x18,0x95,0x89,0xC0,0x18,0x95,0x18,0x95,
0x18,0x95,0x18,0x95,0x18,0x95,0x18,0x95,0x18,0x95,0x18,0x95,0x18,0x95,0x18,0x95,
0x18,0x95,0x18,0x95,0x18,0x95,0x18,0x95,0x18,0x95,0x18,0x95,0x18,0x95,0x70,0xC0,
0x18,0x95,0x18,0x95,0x27,0x00,0xF1,0x01,0x00,0x00,0x91,0x00,0x60,0x01,0x10,0x0E,
	// End of Flash
};
#endif

#endif
