////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file	eeprom.c
/// @author	Simon Qian(webmaster@SimonQian.com)
/// @date	Last Update on 2008-04-07
/// @brief	EEPROM Functions
/// @par	license
/// 		AVRminiProg is distributed under the terms and conditions of GPLv2, see License.txt
////////////////////////////////////////////////////////////////////////////////////////////////////

#include <avr/io.h>

#include "../type.h"
#include "../app_cfg.h"

#ifndef EEPE
#define EEPE EEWE
#endif

#ifndef EEMPE
#define EEMPE EEMWE
#endif

#if AVRP_ISP_SHOULD_ENABLE
/// Write EEPROM
/// @param[in]	Addr	Address of EEPROM
/// @param[in]	Data	Data to write
void EEPROM_Write(uint16 Addr,uint8 Data)
{
	// Wait for completion of previous write
	loop_until_bit_is_clear(EECR,EEPE);

	EEAR	= Addr;
	EEDR	= Data;

	EECR	|= _BV(EEMPE);
	EECR	|= _BV(EEPE);
}

/// Read EEPROM
/// @param[in]	Addr	Address of EEPROM
/// @return		Data read
uint8 EEPROM_Read(uint16 Addr)
{
	loop_until_bit_is_clear(EECR,EEPE);

	EEAR	= Addr;

	EECR	|= _BV(EERE);

	return EEDR;
}
#endif		// #if AVRP_ISP_SHOULD_ENABLE
