////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file	app_cfg.h
/// @author	Simon Qian(webmaster@SimonQian.com)
/// @date	Last Update on 2008-04-07
/// @brief	application configuration file
/// @par	license
/// 		AVRminiProg is distributed under the terms and conditions of GPLv2, see License.txt
////////////////////////////////////////////////////////////////////////////////////////////////////

// Include this if use AVRminiProg_Full
#include "app_cfg_Full.h"
// Include this if use AVRminiProg_USBasp
//#include "app_cfg_USBasp.h"
// Include this if use AVRminiProg_Tiny, not implemented, DO NOT USE
//#include "app_cfg_Tiny.h"


/// AVRISP mkII from Atmel
#define AVR_DEVICE_AVRISP_MKII		0x01
/// JTAGICE mkII from Atmel
#define AVR_DEVICE_JTAGICE_MKII		0x02
/// AVR Dragon from Atmel
#define AVR_DEVICE_AVRDRAGON		0x03
/// STK600 from Atmel, not implemented, DO NOT USE
#define AVR_DEVICE_STK600			0x04
#define AVR_DEVICE_AVRPHENIX		0x80
#define AVR_DEVICE_AVRPHENIX_ONLY	0x40

// different version of AVR Studio will support different version of devices
// How to get the version of device according to your AVR Studio:
// 'Help' menu --> AVR Tools User Guide,Check the 'What's New' section of device help
// The first version number word is Master MCU verion,the last is Slave MCU version.
// The first version number byte is major version,the last is minor version(minor version can also set to 0xFF)
// for example(AVRISP mkII):December 4th, 2007 - AVR Studio 4.13 SP2 - FW 01.06
// 							01 is Major Version,06 is Minor Version
// for example(AVRDragon):	November 21st, 2007 - Sw: 0x0101 0x0200 (released with AVR Studio 4.13 SP2)
// 							0x0101 is for Master MCU,0x0200 is for Slave MCU(0x02 is Major Version,0x00 is Minor Version)
// If AVRStudio 4.13SP2 b571 is used,use default version settings
// If Other version is used, only Firmware Version(see comment) should be updated commonly.
// AVRISP mkII
#define AVRISP_mkII_HW_VER			0x11
#define AVRISP_mkII_BUILD_NUMBER	0x0000
#define AVRISP_mkII_FW_MAJOR_VER	0x11	// Firmware Major Version
#define AVRISP_mkII_FW_MINOR_VER	0x11	// Firmware Minor Version

// JTAGICE mkII
#define JTAGICE_mkII_HW_VER			0x0000
#define JTAGICE_mkII_COMM_ID		0x11
#define JTAGICE_mkII_SerialNumber	{0x00,0xA2,0x00,0x00,0x01,0x1E}
// Master Version
#define JTAGICE_mkII_MBootload_VER	0xFF
#define JTAGICE_mkII_MFW_MAJOR_VER	0x05	// Firmware Major Version for Master MCU
#define JTAGICE_mkII_MFW_MINOR_VER	0x23	// Firmware Minor Version for Master MCU
// Slave Version
#define JTAGICE_mkII_SBootload_VER	0xFF
#define JTAGICE_mkII_SFW_MAJOR_VER	0x05	// Firmware Major Version for Slave MCU
#define JTAGICE_mkII_SFW_MINOR_VER	0x23	// Firmware Minor Version for Slave MCU

// AVRDragon
#define AVRDragon_HW_VER			0x0102
#define AVRDragon_COMM_ID			0x01
#define AVRDragon_SerialNumber		{0x00,0xA2,0x00,0x00,0x01,0x1E}
// Master Version
#define AVRDragon_MBootload_VER		0xFF
#define AVRDragon_MFW_MAJOR_VER		0x01	// Firmware Major Version for Master MCU
#define AVRDragon_MFW_MINOR_VER		0xFF	// Firmware Minor Version for Master MCU
// Slave Version
#define AVRDragon_SBootload_VER		0xFF
#define AVRDragon_SFW_MAJOR_VER		0x02	// Firmware Major Version for Slave MCU
#define AVRDragon_SFW_MINOR_VER		0xFF	// Firmware Minor Version for Slave MCU





#ifndef APP_CFG_INCLUDED
#define APP_CFG_INCLUDED

#define AVR_DEVICE					(AVR_DEVICE_AVRISP_MKII | 0)

// if AVR_DEVICE_AVRISP_MKII is sellected, only ISP could be enabled, others will be ignored
// if AVR_DEVICE_JTAGICE_MKII is sellected, HV Programming will be ignored
#define AVR_PROG_ISP_EN				1
#define AVR_PROG_JTAG_EN			1
#define AVR_PROG_HVPP_EN			0
#define AVR_PROG_HVSP_EN			0
#define AVRX_PROG_JTAG_EN			0
#define AVRX_PROG_PDI_EN			0
#define AVR32_PROG_JTAG_EN			0

#define AVR_DBG_JTAG_EN				0			// no implemented, don't use
#define AVR_DBG_DW_EN				0			// no implemented, don't use

/*************************** ADC *****************************/
/// devices like USBasp has no AD connected to target VCC,just define AD_En to 0
#define AD_En						1

/// VREF can be ADC_VREF_AVCC or ADC_VREF_BANDGAP
#define AD_VCC_MUX					(ADC_VREF_AVCC | ADC_CHANNEL_ADC0)
/// Voltage of AD Reference(in 100mA,so 11 means 1.1V)
#define ADVref						37			// in 100mA,so 11 means 1.1V
/// target VCC ------ resistor1 -------------- ADC
///                                   |
///        GND ------ resistor2 ------
/// 
/// AD_VCC_RATE equals to (resistor1 + resistor2) / resistor2
/// for Reference Voltage (AVCC will change according to different current load, BANDGAP will not):
/// if AVCC is used, resistor1 = resistor2 = 10K					AD_VCC_RATE should be 2
/// if BANDGAP is used, resistor1 = 10K, resistor2 = 2K			AD_VCC_RATE should be 6
/// I use AVCC as reference, and resistor1 = 10K, resistor2 = 2K	AD_VCC_RATE is 6
/// Of cource other values are also acceptable, just use different resistor1 and resistor2.
#define AD_VCC_RATE					6

/*************************** LED *****************************/
/// LED used to indicate connected to PC
#define LED_Green					P(1)
/// LED used to indicate Target VCC
#define LED_Red						P(3)

/// LED Initialization
#define LED_Init()					do{PortD_SetPin(LED_Green | LED_Red);PortD_SetOutput(LED_Green | LED_Red);}while(0)
/// Turn LED on
#define LED_On(led)					PortD_ClrPin(led)
/// Turn LED off
#define LED_Off(led)				PortD_SetPin(led)
/// LED Is on?
#define LED_IsOn(led)				!PortD_GetPin(led)


/*********************** ISP JTAG *****************************/
/// AVRminiProg will check the Target VCC, and determine whether to supply power to JTAG/ISP, AD_En MUST be set to 1
#define ISP_JTAG_AutoPower_En		1
/// AVRminiProg can force supply power to JTAG/ISP without check if power supply is needed, to use this ISP_JTAG_AutoPower_En MUST be set to 1
#define ISP_JTAG_FourcePower_En		1

/// Cotrol over Power on ISP or JTAG, recommended to be the same pin as PP_PWR_CTL
#define ISP_JTAG_PowerCtrl			P(3)
/// Power Control Initialization
#define ISP_JTAG_PowerInit()		//(PortA_SetPin(ISP_JTAG_PowerCtrl),PortA_SetOutput(ISP_JTAG_PowerCtrl))
/// Power Control Finilization
#define ISP_JTAG_PowerFini()		//
/// Turn Power on
#define ISP_JTAG_PowerOn()			HV_TargetVCC_On()//PortA_ClrPin(ISP_JTAG_PowerCtrl)
/// Turn Power off
#define ISP_JTAG_PowerOff()			HV_TargetVCC_Off()//(PortA_SetPin(ISP_JTAG_PowerCtrl)

/*************************** JTAG *****************************/
/// STRONGLY recommended to be the same pin as SPI_SS
#define JTAG_TAP_TMS				P(6)
// MUST be SPI0 as ISP interface,so that one adaptor is enough for both ISP and JTAG.
/// MUST be the same PIN as SPI_SCK
#define JTAG_TAP_TCK				P(5)
/// MUST be the same PIN as SPI_MOSI
#define JTAG_TAP_TDI				P(3)
/// MUST be the same PIN as SPI_MISO
#define JTAG_TAP_TDO				P(4)

/// Set TMS Pin to Output
#define JTAG_TAP_TMS_SETOUTPUT()	PortD_SetOutput(JTAG_TAP_TMS)
/// Set TMS Pin to Input
#define JTAG_TAP_TMS_SETINPUT()		PortD_SetInput(JTAG_TAP_TMS)
/// Set TMS Pin High
#define JTAG_TAP_TMS_SET()			PortD_SetPin(JTAG_TAP_TMS)
/// Set TMS Pin Low
#define JTAG_TAP_TMS_CLR()			PortD_ClrPin(JTAG_TAP_TMS)

/// Set TCK Pin to Output
#define JTAG_TAP_TCK_SETOUTPUT()	PortB_SetOutput(JTAG_TAP_TCK)
/// Set TCK Pin to Input
#define JTAG_TAP_TCK_SETINPUT()		PortB_SetInput(JTAG_TAP_TCK)
/// Set TCK Pin High
#define JTAG_TAP_TCK_SET()			PortB_SetPin(JTAG_TAP_TCK)
/// Set TCK Pin Low
#define JTAG_TAP_TCK_CLR()			PortB_ClrPin(JTAG_TAP_TCK)

/// Set TDI Pin Output
#define JTAG_TAP_TDI_SETOUTPUT()	PortB_SetOutput(JTAG_TAP_TDI)
/// Set TDI Pin Input
#define JTAG_TAP_TDI_SETINPUT()		PortB_SetInput(JTAG_TAP_TDI)
/// Set TDI Pin High
#define JTAG_TAP_TDI_SET()			PortB_SetPin(JTAG_TAP_TDI)
/// Set TDI Pin Low
#define JTAG_TAP_TDI_CLR()			PortB_ClrPin(JTAG_TAP_TDI)

/// Set TDO Pin to Output
#define JTAG_TAP_TDO_SETINPUT()		PortB_SetInput(JTAG_TAP_TDO)
/// Get TDO Pin
#define JTAG_TAP_TDO_GET()			PortB_GetPin(JTAG_TAP_TDO)
/// Pullup TDO Pin
#define JTAG_TAP_TDO_SET()			PortB_SetPin(JTAG_TAP_TDO)
/// Cancel pullup on TDO Pin
#define JTAG_TAP_TDO_CLR()			PortB_ClrPin(JTAG_TAP_TDO)

/*************************** ISP *****************************/
/// if error occurs during programming with AutoSpeed set,
/// just set ISP speed in AVRSutdio and AVRminiProg will disable AutoSpeed
/// If U don't like it, change ISP_AutoSpeed_En to 0
/// If used, an 12M or 15M osc is recommended
/// There is some other configurations in ISP.h file. If problems occur, define this to 0
#define ISP_AutoSpeed_En			1

/// SPI Port for ISP(SPI0 Must be used)
#define SPI_MISO					P(4)
/// SPI Port for ISP(SPI0 Must be used)
#define SPI_MOSI					P(3)
/// SPI Port for ISP(SPI0 Must be used)
#define SPI_SCK						P(5)
/// SPI Port for ISP(SPI0 Must be used)
#define SPI_SS						P(2)

/// in Master SPI mode,if SS is input, SS MUST be held high to ensure master SPI operation
/// so configure SS to output or input with pullup, just sellect one below
/// undefine both if SS pin is used as RESET control like USBasp
/// SPI_SS is strongly recommended as ISP_RST and JTAG_TAP_TMS, and undefine both
#define SPI_SS_Init()				do{PortB_SetPin(SPI_SS);PortB_SetInput(SPI_SS);}while(0)
//#define SPI_SS_Init()				PortB_SetOutput(SPI_SS)

/// Set MOSI Pin to Output
#define SPI_SetMOSIOutput()			PortB_SetOutput(SPI_MOSI)
/// Set MOSI Pin to Input
#define SPI_SetMOSIInput()			PortB_SetInput(SPI_MOSI)
/// Set MOSI Pin High
#define SPI_SetMOSI()				PortB_SetPin(SPI_MOSI)
/// Set MOSI Pin Low
#define SPI_ClrMOSI()				PortB_ClrPin(SPI_MOSI)

/// Set MISO Pin to Input
#define SPI_SetMISOInput()			PortB_SetInput(SPI_MISO)
/// Get MISO Pin
#define SPI_GetMISO()				PortB_GetPin(SPI_MISO)

/// Set SCK Pin to Output
#define SPI_SetSCKOutput()			PortB_SetOutput(SPI_SCK)
/// Set SCK Pin to Input
#define SPI_SetSCKInput()			PortB_SetInput(SPI_SCK)
/// Set SCK Pin to High
#define SPI_SetSCK()				PortB_SetPin(SPI_SCK)
/// Set SCK Pin to Low
#define SPI_ClrSCK()				PortB_ClrPin(SPI_SCK)

/// STRONGLY recommended to be the same pin as SPI_SS
#define ISP_RST						P(7)
/// Set Reset Pin High
#define ISP_SetRST()				PortD_SetPin(ISP_RST)
/// Set Reset Pin Low
#define ISP_ClrRST()				PortD_ClrPin(ISP_RST)
/// Set Reset Pin to Output
#define ISP_SetRSTOutput()			PortD_SetOutput(ISP_RST)
/// Set Reset Pin to Input
#define ISP_SetRSTInput()			PortD_SetInput(ISP_RST)

/**************************** HV ******************************/
/// HV_Test_TVCC_12V is used when U test TVCC and V12 control.It will just toggle TVCC and V12 when power on and U just check the signal.
#define HV_Test_TVCC_12V			0
/// Set this to 0 if you have another 12V
/// Set this to 1 to generate PWM to control Boost circuit
#define HV_12V_EN					1

#define PP_RST_CTL					P(4)
#define PP_RST_HZ_CTL				P(5)
#define PP_PWR_CTL					P(3)

/// HV Control Device Initialization
#define HV_TargetReset_InitDev()	(HV_TargetReset_HZ(),PortA_SetOutput(PP_RST_HZ_CTL | PP_RST_CTL))
/// HV Control Initialization
#define HV_TargetReset_Init()		HV_TargetReset_HZ()
/// HV Control Finilization
#define HV_TargetReset_Fini()		HV_TargetReset_HZ()
/// Set HV to HighZ
#define HV_TargetReset_HZ()			(PortA_ClrPin(PP_RST_HZ_CTL | PP_RST_CTL))
/// Set HV to 12V
#define HV_TargetReset_12V()		(PortA_SetPin(PP_RST_HZ_CTL),PortA_ClrPin(PP_RST_CTL))
/// Set HV to 0V
#define HV_TargetReset_0V()			(PortA_SetPin(PP_RST_HZ_CTL | PP_RST_CTL))

/// VCC Control Initialization
#define HV_TargetVCC_Init()			(PortA_SetPin(PP_PWR_CTL),PortA_SetOutput(PP_PWR_CTL))
/// VCC Control Finilization
#define HV_TargetVCC_Fini()			PortA_SetInput(PP_PWR_CTL)
/// VCC on
#define HV_TargetVCC_On()			PortA_ClrPin(PP_PWR_CTL)
/// VCC off
#define HV_TargetVCC_Off()			PortA_SetPin(PP_PWR_CTL)

// 12V ------ R3 ------ ADC
//                    |
// GND ------ R4 ------
#define HV_12V_Sample_MUX			(ADC_VREF_BANDGAP | ADC_CHANNEL_ADC7)
#define HV_12V_Sample_Thre			822					// ((12V * R4 / (R3 + R4)) / Vbandgap) * 1024
#define HV_12V_Sample_Delta			15					// ((DeltaV * R4 / (R3 + R4)) / Vbandgap) * 1024
/// Boost Circuit Initialization
#define HV_Boost_Init()				(Boost_Stable = 0,HV_Boost_SetRate(0),PortD_SetOutput(P(7)),TCCR2 = (1 << WGM20) | (1 << WGM21) | (1 << COM21) | 1,ADMUX = HV_12V_Sample_MUX,ADC_SetINTEnable(),ADC_Start())
/// Boost Circuit Finilization
#define HV_Boost_Fini()				(Boost_Stable = 0,ADC_SetINTDisable(),HV_Boost_SetRate(0),PortD_SetInput(P(7)),TCCR2 = 0)
/// Boost Circuit Get PWM Rete
#define HV_Boost_GetRate()			OCR2
/// Boost Circuit Set PWM Rete
#define HV_Boost_SetRate(ocr)		(OCR2 = ocr)

/*************************** HVPP *****************************/
// HVPP Interfaces:
// XTAL1
// Ctrl Port:
// 7(O)    6(O)    5(O)    4(O) |  3(O)    2(O)    1(I)    0(O)
// PAGEL   XA1     XA0     BS1  |  nWR     nOE     RDY     BS2

#define HVPP_DATA_PORT_NAME				B
#define HVPP_CTRL_PORT_NAME				C

#define HVPP_XTAL1						P(2)
/// Set XTAL1 Pin to Output
#define HVPP_XTAL1_SetOutput()			PortC_SetOutput(HVPP_XTAL1)
/// Set XTAL1 Pin to Input
#define HVPP_XTAL1_SetInput()			PortC_SetInput(HVPP_XTAL1)
/// Set XTAL1 Pin Low
#define HVPP_XTAL1_Clr()				PortC_ClrPin(HVPP_XTAL1)
/// Set XTAL1 Pin High
#define HVPP_XTAL1_Set()				PortC_SetPin(HVPP_XTAL1)

#define HVPP_SignalDelay_InUS			0		// undefine this if no delay is needed

/*************************** HVSP *****************************/
// HVSP Interfaces:
// SDO
// SDI
// SII
// SCI
#define HVSP_SDO						P(1)
#define HVSP_SII						P(2)
#define HVSP_SDI						P(3)
#define HVSP_SCI						P(4)

/// Set SDO Pin to Output
#define HVSP_SDO_SetOutput()			PortA_SetOutput(HVSP_SDO)
/// Set SDI Pin to Input
#define HVSP_SDO_SetInput()				PortA_SetInput(HVSP_SDO)
/// Set SDO Pin High
#define HVSP_SDO_Set()					PortA_SetPin(HVSP_SDO)
/// Set SDO Pin Low
#define HVSP_SDO_Clr()					PortA_ClrPin(HVSP_SDO)
/// Get SDO Pin
#define HVSP_SDO_Get()					PortA_GetPin(HVSP_SDO)

/// Set SDI Pin to Output
#define HVSP_SDI_SetOutput()			PortA_SetOutput(HVSP_SDI)
/// Set SDI Pin to Input
#define HVSP_SDI_SetInput()				PortA_SetInput(HVSP_SDI)
/// Set SDI Pin to High
#define HVSP_SDI_Set()					PortA_SetPin(HVSP_SDI)
/// Set SDI Pin to Low
#define HVSP_SDI_Clr()					PortA_ClrPin(HVSP_SDI)

/// Set SII Pin to Output
#define HVSP_SII_SetOutput()			PortA_SetOutput(HVSP_SII)
/// Set SII Pin to Input
#define HVSP_SII_SetInput()				PortA_SetInput(HVSP_SII)
/// Set SII Pin High
#define HVSP_SII_Set()					PortA_SetPin(HVSP_SII)
/// Set SII Pin Low
#define HVSP_SII_Clr()					PortA_ClrPin(HVSP_SII)

/// Set SCI Pin to Output
#define HVSP_SCI_SetOutput()			PortA_SetOutput(HVSP_SCI)
/// Set SCI Pin to Input
#define HVSP_SCI_SetInput()				PortA_SetInput(HVSP_SCI)
/// Set SCI Pin to High
#define HVSP_SCI_Set()					PortA_SetPin(HVSP_SCI)
/// Set SCI Pin to Low
#define HVSP_SCI_Clr()					PortA_ClrPin(HVSP_SCI)

#define HVSP_ClrAltProgEnablePin()		(PortC_SetOutput(0x07),PortC_ClrPin(0x07))

/*************************** AVRUSB *****************************/
/* ---------------------------- Hardware Config ---------------------------- */
#define USB_CFG_IOPORTNAME      D
/* This is the port where the USB bus is connected. When you configure it to
 * "B", the registers PORTB, PINB and DDRB will be used.
 */
#define USB_CFG_DMINUS_BIT      4
/* This is the bit number in USB_CFG_IOPORT where the USB D- line is connected.
 * This may be any bit in the port.
 */
#define USB_CFG_DPLUS_BIT       2
/* This is the bit number in USB_CFG_IOPORT where the USB D+ line is connected.
 * This may be any bit in the port. Please note that D+ must also be connected
 * to interrupt pin INT0!
 */
#define USB_CFG_CLOCK_KHZ       (F_CPU/1000)
/* Clock rate of the AVR in MHz. Legal values are 12000, 15000, 16000 or 16500.
 * The 16.5 MHz version of the code requires no crystal, it tolerates +/- 1%
 * deviation from the nominal frequency. All other rates require a precision
 * of 2000 ppm and thus a crystal!
 * Default if not specified: 12 MHz
 */
/* ----------------------- Optional Hardware Config ------------------------ */

/* #define USB_CFG_PULLUP_IOPORTNAME   D */
/* If you connect the 1.5k pullup resistor from D- to a port pin instead of
 * V+, you can connect and disconnect the device from firmware by calling
 * the macros usbDeviceConnect() and usbDeviceDisconnect() (see usbdrv.h).
 * This constant defines the port on which the pullup resistor is connected.
 */
/* #define USB_CFG_PULLUP_BIT          4 */
/* This constant defines the bit number in USB_CFG_PULLUP_IOPORT (defined
 * above) where the 1.5k pullup resistor is connected. See description
 * above for details.
 */

/*************************** KEY *****************************/
#define PROGKEY_Pin					(1 << 0)
/// Program Key Initialization
#define PROGKEY_Init()				do{PortD_SetPin(PROGKEY_Pin);PortD_SetInput(PROGKEY_Pin);}while(0)
/// Check Program Key
#define PROGKEY_IsDown()			!PortD_GetPin(PROGKEY_Pin)


#endif		// #ifndef APP_CFG_INCLUDED






/// Define which device from Atmel to emulate
#define AVR_DEVICE_ATMEL			(AVR_DEVICE & 0x0F)
/// Define whether to support offline programming
#define AVR_DEVICE_OFFLINE_EN		(AVR_DEVICE & AVR_DEVICE_AVRPHENIX)
/// Define whether to support only offline programming
#define AVR_DEVICE_OFFLINE_ONLY		(AVR_DEVICE & AVR_DEVICE_AVRPHENIX_ONLY)

/// Define whether ISP for AVR Programming should enabled
#define AVRP_ISP_SHOULD_ENABLE		(AVR_PROG_ISP_EN)
/// Define whether JTAG for AVR Programming should enabled
#define AVRP_JTAG_SHOULD_ENABLE		(((AVR_DEVICE_ATMEL == AVR_DEVICE_JTAGICE_MKII) || (AVR_DEVICE_ATMEL == AVR_DEVICE_AVRDRAGON)) && AVR_PROG_JTAG_EN)
/// Define whether HVPP for AVR Programming should enabled
#define AVRP_HVPP_SHOULD_ENABLE		((AVR_DEVICE_ATMEL == AVR_DEVICE_AVRDRAGON) && AVR_PROG_HVPP_EN)
/// Define whether HVSP for AVR Programming should enabled
#define AVRP_HVSP_SHOULD_ENABLE		((AVR_DEVICE_ATMEL == AVR_DEVICE_AVRDRAGON) && AVR_PROG_HVSP_EN)
/// Define whether JTAG for AVR XMega Programming should enabled
#define AVRXP_JTAG_SHOULD_ENABLE	((AVR_DEVICE_ATMEL == AVR_DEVICE_JTAGICE_MKII) && AVRX_PROG_JTAG_EN)
/// Define whether PDI for AVR XMega Programming should enabled
#define AVRXP_PDI_SHOULD_ENABLE		((AVR_DEVICE_ATMEL == AVR_DEVICE_JTAGICE_MKII) && AVRX_PROG_PDI_EN)
/// Define whether JTAG for AVR32 Programming should enabled
#define AVR32P_JTAG_SHOULD_ENABLE	((AVR_DEVICE_ATMEL == AVR_DEVICE_JTAGICE_MKII) && AVR32_PROG_JTAG_EN)

/// Define whether JTAG for AVR Debug should enabled
#define AVRD_JTAG_SHOULD_ENABLE		(((AVR_DEVICE_ATMEL == AVR_DEVICE_JTAGICE_MKII) || (AVR_DEVICE_ATMEL == AVR_DEVICE_AVRDRAGON)) && AVR_DBG_JTAG_EN)
/// Define whether DebugWire for AVR Debug should enabled
#define AVRD_DW_SHOULD_ENABLE		(((AVR_DEVICE_ATMEL == AVR_DEVICE_JTAGICE_MKII) || (AVR_DEVICE_ATMEL == AVR_DEVICE_AVRDRAGON)) && AVR_DBG_DW_EN)

